#
# spec file for package python-fabio
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define packagename fabio
%define skip_python2 1
Name:           python-fabio
Version:        0.14.0
Release:        2.7
Summary:        Image IO for images produced by 2D X-ray detectors
License:        BSD-3-Clause AND GPL-2.0-or-later AND LGPL-3.0-or-later AND MIT
URL:            https://github.com/silx-kit/fabio
Source:         https://github.com/silx-kit/fabio/archive/v%{version}.tar.gz#/%{packagename}-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module numpy >= 1.19.1}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Requires:       python-h5py
Requires:       python-lxml
Requires:       python-numpy >= 1.19.1
Requires:       python-qt5
Requires(post): update-alternatives
Requires(postun):update-alternatives
# This package does not support 32 bit arch.
ExcludeArch:    i586 %{arm}
%python_subpackages

%description
FabIO is an I/O library for images produced by 2D X-ray detectors.

%prep
%autosetup -n %{packagename}-%{version}
# Fix W: non-executable-script
grep -ElRZ '*.py' . | xargs -0 -l sed -i '/^#!/d'

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/densify-Bragg
%python_clone -a %{buildroot}%{_bindir}/fabio-convert
%python_clone -a %{buildroot}%{_bindir}/fabio_viewer
%python_clone -a %{buildroot}%{_bindir}/eiger2cbf
%python_clone -a %{buildroot}%{_bindir}/eiger2crysalis
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%prepare_alternative fabio-convert fabio_viewer eiger2cbf eiger2crysalis

%post
%python_install_alternative densify-Bragg fabio-convert fabio_viewer eiger2cbf eiger2crysalis

%postun
%python_uninstall_alternative densify-Bragg fabio-convert fabio_viewer eiger2cbf eiger2crysalis

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python ./run_tests.py --installed -v
}

%files %{python_files}
%doc README.rst
%license copyright
%python_alternative %{_bindir}/densify-Bragg
%python_alternative %{_bindir}/fabio-convert
%python_alternative %{_bindir}/fabio_viewer
%python_alternative %{_bindir}/eiger2cbf
%python_alternative %{_bindir}/eiger2crysalis
%{python_sitearch}/%{packagename}
%{python_sitearch}/%{packagename}-%{version}*-info

%changelog
* Tue Nov 29 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python-six dependency
- Remove python_module macro definition
- More specific python_sitelib in %%files
* Fri Jun 10 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.14.0:
  * fix infinite loop when iterating over lima/eiger image files (#468)
  * fix typo when saving in pilatus/CBF format (#471)
  * fix noisy test on densification (#440)
  * limit version of setuptools (related to the PEP517 and associated regressions)
  * Change logo in documentation
  * Support for Python versions 3.6 to 3.10, tested on amd64, ppc64le and arm64
  * Linux is officially the main platform, Windows and MacOS are supported in best effort mode.
* Thu Apr 21 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.13.0:
  * Allow files to be larger than 2GB (Thanks Wout)
  * Simplify the eiger2cbf tool
  * Correct densification with missing wavelength
  * Correct issue with EDF headers (#459)
  * Support for Python versions 3.6 to 3.10, tested on amd64, ppc64le and
    arm64
  * Densification of sparse data (densify-Bragg) produced by pyFAI
    (sparsify-Bragg)
  * Writer for EigerImage format
  * Writer for LimaImage format
  * Refactor all CLI tools
  * Disable the mask calculation by default in eiger2crysalis
  * Clean-up some debuging prints in CbfImage
  * Correct MrcImage format (and change in tests)
- Use run_tests rather than setup.py tests to run the testsuite.
* Fri Feb 19 2021 andy great <andythe_great@pm.me>
- Update to version 0.11.0.
  * New support for Esperanto image format
    (includes bitfield compression) read & write
  * New support for HDF5 files generated by LImA (read-only so far)
  * New support for HDF5 files generated by Bragg-sparsify
    (definitevely read-only)
  * Improved support for CBF: Magic bytes, headers, + other bug
    corrections
  * Improved supportfor Tiff: Miss interpretation of colormap tags
  * Improved support for GE files gernerated at APS
  * Improved support for Bruker100 image format (read & write)
  * Stop testing for 32-bit operating systems.
- Removed fix_test_brukerimage.py_assertionerror.patch, which was
  included in upstream.
* Fri Feb 19 2021 andy great <andythe_great@pm.me>
- Skip python36 because python-numpy does not support it.
* Sun Sep  6 2020 andy great <andythe_great@pm.me>
- Initial package release.
